.. :changelog:

History
-------

0.1.8.4 2013-09-04
==================

* Bug Fix : installation via pip was failing due to missing HISTORY.rst file.

0.1.8.3 2013-08-12
==================

* Bug fix 

  - improved error handling and logging for missing/malformed config file.

0.1.8 2013-03-18
================ 

* Added iphone/android/phantomjs to supported browsers 
* Bug fix 
  
  - fixed phantomjs build in travis




